@@ -52,13 +52,14 @@ def connect(args, conn=None, **kwargs):
     db = DB(conn or args.database, tracer=tracer if args.verbose >= 2 else None, **kwargs)  # type: ignore
     with db.conn:
         db.conn.execute("PRAGMA main.cache_size = 8000")
+
+    db.enable_wal()
     return db
 
 
 def optimize(args) -> None:
     print("\nOptimizing database")
     db = args.db
-    db.enable_wal()
 
     config = {
         "media": {
@@ -125,7 +126,7 @@ def optimize(args) -> None:
                     replace=True,
                     tokenize="trigram"
                     if sqlite3.sqlite_version_info >= (3, 34, 0)
-                    else None,  # https://www.sqlite.org/releaselog/3_34_0.html
+                    else 'unicode61 "tokenchars=_."',  # https://www.sqlite.org/releaselog/3_34_0.html
                 )
             else:
                 with db.conn:
